==> tekton-model-triggers-v1alpha1-6.2.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/GitHubInterceptorFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GitHubInterceptorFluentImpl<A extends GitHubInterceptorFluent<A>> extends BaseFluent<A> implements GitHubInterceptorFluent<A>{
  public GitHubInterceptorFluentImpl() {
  }
  public GitHubInterceptorFluentImpl(GitHubInterceptor instance) {
    this.withEventTypes(instance.getEventTypes()); 
    this.withSecretRef(instance.getSecretRef()); 
  }
  private List<String> eventTypes = new ArrayList<String>();
  private SecretRefBuilder secretRef;
  public A addToEventTypes(Integer index,String item) {
    if (this.eventTypes == null) {this.eventTypes = new ArrayList<String>();}
    this.eventTypes.add(index, item);
    return (A)this;
  }
  public A setToEventTypes(Integer index,String item) {
    if (this.eventTypes == null) {this.eventTypes = new ArrayList<String>();}
    this.eventTypes.set(index, item); return (A)this;
  }
  public A addToEventTypes(java.lang.String... items) {
    if (this.eventTypes == null) {this.eventTypes = new ArrayList<String>();}
    for (String item : items) {this.eventTypes.add(item);} return (A)this;
  }
  public A addAllToEventTypes(Collection<String> items) {
    if (this.eventTypes == null) {this.eventTypes = new ArrayList<String>();}
    for (String item : items) {this.eventTypes.add(item);} return (A)this;
  }
  public A removeFromEventTypes(java.lang.String... items) {
    for (String item : items) {if (this.eventTypes!= null){ this.eventTypes.remove(item);}} return (A)this;
  }
  public A removeAllFromEventTypes(Collection<String> items) {
    for (String item : items) {if (this.eventTypes!= null){ this.eventTypes.remove(item);}} return (A)this;
  }
  public List<String> getEventTypes() {
    return this.eventTypes;
  }
  public String getEventType(Integer index) {
    return this.eventTypes.get(index);
  }
  public String getFirstEventType() {
    return this.eventTypes.get(0);
  }
  public String getLastEventType() {
    return this.eventTypes.get(eventTypes.size() - 1);
  }
  public String getMatchingEventType(Predicate<String> predicate) {
    for (String item: eventTypes) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingEventType(Predicate<String> predicate) {
    for (String item: eventTypes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withEventTypes(List<String> eventTypes) {
    if (eventTypes != null) {this.eventTypes = new ArrayList(); for (String item : eventTypes){this.addToEventTypes(item);}} else { this.eventTypes = null;} return (A) this;
  }
  public A withEventTypes(java.lang.String... eventTypes) {
    if (this.eventTypes != null) {this.eventTypes.clear();}
    if (eventTypes != null) {for (String item :eventTypes){ this.addToEventTypes(item);}} return (A) this;
  }
  public Boolean hasEventTypes() {
    return eventTypes != null && !eventTypes.isEmpty();
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretRef getSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public SecretRef buildSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public A withSecretRef(SecretRef secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new SecretRefBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} else { this.secretRef = null; _visitables.get("secretRef").remove(this.secretRef); } return (A) this;
  }
  public Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(String secretKey,String secretName) {
    return (A)withSecretRef(new SecretRef(secretKey, secretName));
  }
  public GitHubInterceptorFluent.SecretRefNested<A> withNewSecretRef() {
    return new GitHubInterceptorFluentImpl.SecretRefNestedImpl();
  }
  public GitHubInterceptorFluent.SecretRefNested<A> withNewSecretRefLike(SecretRef item) {
    return new GitHubInterceptorFluentImpl.SecretRefNestedImpl(item);
  }
  public GitHubInterceptorFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public GitHubInterceptorFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new SecretRefBuilder().build());
  }
  public GitHubInterceptorFluent.SecretRefNested<A> editOrNewSecretRefLike(SecretRef item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GitHubInterceptorFluentImpl that = (GitHubInterceptorFluentImpl) o;
    if (eventTypes != null ? !eventTypes.equals(that.eventTypes) :that.eventTypes != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(eventTypes,  secretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (eventTypes != null && !eventTypes.isEmpty()) { sb.append("eventTypes:"); sb.append(eventTypes + ","); }
    if (secretRef != null) { sb.append("secretRef:"); sb.append(secretRef); }
    sb.append("}");
    return sb.toString();
  }
  class SecretRefNestedImpl<N> extends SecretRefFluentImpl<GitHubInterceptorFluent.SecretRefNested<N>> implements GitHubInterceptorFluent.SecretRefNested<N>,Nested<N>{
    SecretRefNestedImpl(SecretRef item) {
      this.builder = new SecretRefBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new SecretRefBuilder(this);
    }
    SecretRefBuilder builder;
    public N and() {
      return (N) GitHubInterceptorFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/GitHubInterceptorFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GitHubInterceptorFluentImpl<A extends GitHubInterceptorFluent<A>> extends BaseFluent<A> implements GitHubInterceptorFluent<A>{
  public GitHubInterceptorFluentImpl() {
  }
  public GitHubInterceptorFluentImpl(GitHubInterceptor instance) {
    if (instance != null) {
      this.withEventTypes(instance.getEventTypes());
      this.withSecretRef(instance.getSecretRef());
    }
  }
  private List<String> eventTypes = new ArrayList<String>();
  private SecretRefBuilder secretRef;
  public A addToEventTypes(int index,String item) {
    if (this.eventTypes == null) {this.eventTypes = new ArrayList<String>();}
    this.eventTypes.add(index, item);
    return (A)this;
  }
  public A setToEventTypes(int index,String item) {
    if (this.eventTypes == null) {this.eventTypes = new ArrayList<String>();}
    this.eventTypes.set(index, item); return (A)this;
  }
  public A addToEventTypes(java.lang.String... items) {
    if (this.eventTypes == null) {this.eventTypes = new ArrayList<String>();}
    for (String item : items) {this.eventTypes.add(item);} return (A)this;
  }
  public A addAllToEventTypes(Collection<String> items) {
    if (this.eventTypes == null) {this.eventTypes = new ArrayList<String>();}
    for (String item : items) {this.eventTypes.add(item);} return (A)this;
  }
  public A removeFromEventTypes(java.lang.String... items) {
    for (String item : items) {if (this.eventTypes!= null){ this.eventTypes.remove(item);}} return (A)this;
  }
  public A removeAllFromEventTypes(Collection<String> items) {
    for (String item : items) {if (this.eventTypes!= null){ this.eventTypes.remove(item);}} return (A)this;
  }
  public List<String> getEventTypes() {
    return this.eventTypes;
  }
  public String getEventType(int index) {
    return this.eventTypes.get(index);
  }
  public String getFirstEventType() {
    return this.eventTypes.get(0);
  }
  public String getLastEventType() {
    return this.eventTypes.get(eventTypes.size() - 1);
  }
  public String getMatchingEventType(Predicate<String> predicate) {
    for (String item: eventTypes) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingEventType(Predicate<String> predicate) {
    for (String item: eventTypes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withEventTypes(List<String> eventTypes) {
    if (eventTypes != null) {this.eventTypes = new ArrayList(); for (String item : eventTypes){this.addToEventTypes(item);}} else { this.eventTypes = null;} return (A) this;
  }
  public A withEventTypes(java.lang.String... eventTypes) {
    if (this.eventTypes != null) {this.eventTypes.clear(); _visitables.remove("eventTypes"); }
    if (eventTypes != null) {for (String item :eventTypes){ this.addToEventTypes(item);}} return (A) this;
  }
  public Boolean hasEventTypes() {
    return eventTypes != null && !eventTypes.isEmpty();
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretRef getSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public SecretRef buildSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public A withSecretRef(SecretRef secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new SecretRefBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} else { this.secretRef = null; _visitables.get("secretRef").remove(this.secretRef); } return (A) this;
  }
  public Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(String secretKey,String secretName) {
    return (A)withSecretRef(new SecretRef(secretKey, secretName));
  }
  public GitHubInterceptorFluentImpl.SecretRefNested<A> withNewSecretRef() {
    return new GitHubInterceptorFluentImpl.SecretRefNestedImpl();
  }
  public GitHubInterceptorFluentImpl.SecretRefNested<A> withNewSecretRefLike(SecretRef item) {
    return new GitHubInterceptorFluentImpl.SecretRefNestedImpl(item);
  }
  public GitHubInterceptorFluentImpl.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public GitHubInterceptorFluentImpl.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new SecretRefBuilder().build());
  }
  public GitHubInterceptorFluentImpl.SecretRefNested<A> editOrNewSecretRefLike(SecretRef item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitHubInterceptorFluentImpl that = (GitHubInterceptorFluentImpl) o;
    if (!java.util.Objects.equals(eventTypes, that.eventTypes)) return false;

    if (!java.util.Objects.equals(secretRef, that.secretRef)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(eventTypes,  secretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (eventTypes != null && !eventTypes.isEmpty()) { sb.append("eventTypes:"); sb.append(eventTypes + ","); }
    if (secretRef != null) { sb.append("secretRef:"); sb.append(secretRef); }
    sb.append("}");
    return sb.toString();
  }
  class SecretRefNestedImpl<N> extends SecretRefFluentImpl<GitHubInterceptorFluentImpl.SecretRefNested<N>> implements GitHubInterceptorFluentImpl.SecretRefNested<N>,Nested<N>{
    SecretRefNestedImpl(SecretRef item) {
      this.builder = new SecretRefBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new SecretRefBuilder(this);
    }
    SecretRefBuilder builder;
    public N and() {
      return (N) GitHubInterceptorFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}
